==> roccat-tools-1.0.0.tar.bz2: roccat-tools-1.0.0/roccateventhandler/roccat_dbus_server.c <==
/*
 * This file is part of roccat-tools.
 *
 * roccat-tools is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * roccat-tools is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with roccat-tools. If not, see <http://www.gnu.org/licenses/>.
 */

/* keep inclusion order of following two headers */
#include "roccat_dbus_server.h"
#include "g_cclosure_roccat_marshaller.h"
#include "roccat/roccat.h"

static gboolean roccat_dbus_server_cb_restore_led_rgb(RoccatDBusServer *object, GError **error);
static gboolean roccat_dbus_server_cb_set_led_rgb(RoccatDBusServer *object, guint32 effect, guint32 ambient_color, guint32 event_color, GError **error);

#include "roccat_dbus_server_glue.h"

#define ROCCAT_DBUS_SERVER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST((klass), TYPE_ROCCAT_DBUS_SERVER, RoccatDBusServerClass))
#define IS_ROCCAT_DBUS_SERVER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass), TYPE_ROCCAT_DBUS_SERVER))
#define ROCCAT_DBUS_SERVER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS((obj), TYPE_ROCCAT_DBUS_SERVER, RoccatDBusServerClass))

typedef struct {
	GObjectClass parent;
} RoccatDBusServerClass;

G_DEFINE_TYPE(RoccatDBusServer, roccat_dbus_server, G_TYPE_OBJECT);

enum {
	SET_LED_RGB,
	RESTORE_LED_RGB,
	LAST_SIGNAL,
};

static guint signals[LAST_SIGNAL] = { 0 };

static void roccat_dbus_server_finalize(GObject *object) {
	G_OBJECT_CLASS(roccat_dbus_server_parent_class)->finalize(object);
}

static void roccat_dbus_server_class_init(RoccatDBusServerClass *klass) {
	GObjectClass *object_class;
	object_class = G_OBJECT_CLASS(klass);
	object_class->finalize = roccat_dbus_server_finalize;

	dbus_g_object_type_install_info(TYPE_ROCCAT_DBUS_SERVER, &dbus_glib_server_object_info);

	signals[SET_LED_RGB] = g_signal_new("set-led-rgb", TYPE_ROCCAT_DBUS_SERVER,
			G_SIGNAL_RUN_FIRST | G_SIGNAL_ACTION,
			0, NULL, NULL, g_cclosure_roccat_marshal_VOID__UINT_UINT_UINT_UINT, G_TYPE_NONE,
			4, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_UINT);

	signals[RESTORE_LED_RGB] = g_signal_new("restore-led-rgb", TYPE_ROCCAT_DBUS_SERVER,
			G_SIGNAL_RUN_FIRST | G_SIGNAL_ACTION,
			0, NULL, NULL, g_cclosure_marshal_VOID__UINT, G_TYPE_NONE,
			1, G_TYPE_UINT);
}

static void roccat_dbus_server_init(RoccatDBusServer *object) {}

RoccatDBusServer *roccat_dbus_server_new(void) {
	return g_object_new(TYPE_ROCCAT_DBUS_SERVER, NULL);
}

static gboolean roccat_dbus_server_cb_set_led_rgb(RoccatDBusServer *object,
		guint32 effect, guint32 ambient_color, guint32 event_color, GError **error) {
	g_signal_emit((gpointer)object, signals[SET_LED_RGB], 0, ROCCAT_TALK_DEVICE_ALL, effect, ambient_color, event_color);
	return TRUE;
}

static gboolean roccat_dbus_server_cb_restore_led_rgb(RoccatDBusServer *object, GError **error) {
	g_signal_emit((gpointer)object, signals[RESTORE_LED_RGB], 0, ROCCAT_TALK_DEVICE_ALL);
	return TRUE;
}

gboolean roccat_dbus_server_connect(RoccatDBusServer *dbus_server) {
	DBusGConnection *connection;
	GError *error = NULL;

	connection = dbus_g_bus_get(DBUS_BUS_SESSION, &error);
	if (!connection) {
		g_warning("couldn't get bus %s", error->message);
		return FALSE;
	}

	dbus_g_connection_register_g_object(connection, ROCCAT_DBUS_SERVER_PATH, (GObject *)dbus_server);
	dbus_g_connection_unref(connection);

	return TRUE;
}

==> roccat-tools-3.0.0.tar.bz2: roccat-tools-3.0.0/roccateventhandler/roccat_dbus_server.c <==
/*
 * This file is part of roccat-tools.
 *
 * roccat-tools is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * roccat-tools is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with roccat-tools. If not, see <http://www.gnu.org/licenses/>.
 */

/* keep inclusion order of following two headers */
#include "roccat_dbus_server.h"
#include "g_cclosure_roccat_marshaller.h"
#include "roccat.h"
#include "roccat_talk.h"

static gboolean roccat_dbus_server_cb_restore_led_rgb(RoccatDBusServer *object, GError **error);
static gboolean roccat_dbus_server_cb_set_led_rgb(RoccatDBusServer *object, guint32 effect, guint32 ambient_color, guint32 event_color, GError **error);

#include "roccat_dbus_server_glue.h"

#define ROCCAT_DBUS_SERVER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST((klass), TYPE_ROCCAT_DBUS_SERVER, RoccatDBusServerClass))
#define IS_ROCCAT_DBUS_SERVER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass), TYPE_ROCCAT_DBUS_SERVER))
#define ROCCAT_DBUS_SERVER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS((obj), TYPE_ROCCAT_DBUS_SERVER, RoccatDBusServerClass))

typedef struct {
	GObjectClass parent;
} RoccatDBusServerClass;

G_DEFINE_TYPE(RoccatDBusServer, roccat_dbus_server, G_TYPE_OBJECT);

enum {
	SET_LED_RGB,
	RESTORE_LED_RGB,
	LAST_SIGNAL,
};

static guint signals[LAST_SIGNAL] = { 0 };

static void roccat_dbus_server_finalize(GObject *object) {
	G_OBJECT_CLASS(roccat_dbus_server_parent_class)->finalize(object);
}

static void roccat_dbus_server_class_init(RoccatDBusServerClass *klass) {
	GObjectClass *object_class;
	object_class = G_OBJECT_CLASS(klass);
	object_class->finalize = roccat_dbus_server_finalize;

	dbus_g_object_type_install_info(TYPE_ROCCAT_DBUS_SERVER, &dbus_glib_server_object_info);

	signals[SET_LED_RGB] = g_signal_new("set-led-rgb", TYPE_ROCCAT_DBUS_SERVER,
			G_SIGNAL_RUN_FIRST | G_SIGNAL_ACTION,
			0, NULL, NULL, g_cclosure_roccat_marshal_VOID__UINT_UINT_UINT_UINT, G_TYPE_NONE,
			4, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_UINT);

	signals[RESTORE_LED_RGB] = g_signal_new("restore-led-rgb", TYPE_ROCCAT_DBUS_SERVER,
			G_SIGNAL_RUN_FIRST | G_SIGNAL_ACTION,
			0, NULL, NULL, g_cclosure_marshal_VOID__UINT, G_TYPE_NONE,
			1, G_TYPE_UINT);
}

static void roccat_dbus_server_init(RoccatDBusServer *object) {}

RoccatDBusServer *roccat_dbus_server_new(void) {
	return g_object_new(TYPE_ROCCAT_DBUS_SERVER, NULL);
}

static gboolean roccat_dbus_server_cb_set_led_rgb(RoccatDBusServer *object,
		guint32 effect, guint32 ambient_color, guint32 event_color, GError **error) {
	g_signal_emit((gpointer)object, signals[SET_LED_RGB], 0, ROCCAT_TALK_DEVICE_ALL, effect, ambient_color, event_color);
	return TRUE;
}

static gboolean roccat_dbus_server_cb_restore_led_rgb(RoccatDBusServer *object, GError **error) {
	g_signal_emit((gpointer)object, signals[RESTORE_LED_RGB], 0, ROCCAT_TALK_DEVICE_ALL);
	return TRUE;
}

gboolean roccat_dbus_server_connect(RoccatDBusServer *dbus_server) {
	DBusGConnection *connection;
	GError *error = NULL;

	connection = dbus_g_bus_get(DBUS_BUS_SESSION, &error);
	if (!connection) {
		g_warning("couldn't get bus %s", error->message);
		return FALSE;
	}

	dbus_g_connection_register_g_object(connection, ROCCAT_DBUS_SERVER_PATH, (GObject *)dbus_server);
	dbus_g_connection_unref(connection);

	return TRUE;
}
